@@ -1,26 +1,13 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "serversievesettingstest.h"
 #include "../src/serversievesettings.h"
-#include <QTest>
 #include <QSignalSpy>
+#include <QTest>
 ServerSieveSettingsTest::ServerSieveSettingsTest(QObject *parent)
     : QObject(parent)
 {
@@ -83,19 +70,19 @@ void ServerSieveSettingsTest::shouldEmitSignalWithValueTrue()
     QSignalSpy spy(&widget, &ServerSieveSettings::enableOkButton);
     widget.setServerName(QStringLiteral("foo"));
     QCOMPARE(spy.count(), 1);
-    //We need servername!=empty and username != empty
+    // We need servername!=empty and username != empty
     QCOMPARE(spy.at(0).at(0).toBool(), false);
 
     widget.setUserName(QStringLiteral("foo"));
     QCOMPARE(spy.count(), 2);
     QCOMPARE(spy.at(1).at(0).toBool(), true);
 
-    //We don't want empty string
+    // We don't want empty string
     widget.setUserName(QStringLiteral(" "));
     QCOMPARE(spy.count(), 3);
     QCOMPARE(spy.at(2).at(0).toBool(), false);
 
-    //We don't want empty string
+    // We don't want empty string
     widget.setServerName(QStringLiteral(" "));
     QCOMPARE(spy.count(), 4);
     QCOMPARE(spy.at(3).at(0).toBool(), false);
