@@ -13,7 +13,7 @@ class ImportImapSettingNoFoundPageTest : public QObject
     Q_OBJECT
 public:
     explicit ImportImapSettingNoFoundPageTest(QObject *parent = nullptr);
-    ~ImportImapSettingNoFoundPageTest();
+    ~ImportImapSettingNoFoundPageTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
