@@ -15,7 +15,7 @@ ImportImapSettingNoFoundPage::ImportImapSettingNoFoundPage(QWidget *parent)
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
 
-    QLabel *lab = new QLabel(i18n("No settings found to import."));
+    auto lab = new QLabel(i18n("No settings found to import."));
     QFont font = lab->font();
     font.setBold(true);
     font.setPointSizeF(font.pointSizeF() * 1.5);
