@@ -117,7 +117,7 @@ void ImportImapSettingWizard::next()
 
 void ImportImapSettingWizard::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditorConfigureDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "SieveEditorConfigureDialog");
     const QSize size = group.readEntry("Size", QSize(600, 400));
     if (size.isValid()) {
         resize(size);
@@ -126,7 +126,7 @@ void ImportImapSettingWizard::readConfig()
 
 void ImportImapSettingWizard::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditorConfigureDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "SieveEditorConfigureDialog");
     group.writeEntry("Size", size());
     group.sync();
 }
