@@ -27,7 +27,7 @@ ServerSieveListWidget::~ServerSieveListWidget()
 
 void ServerSieveListWidget::readConfig()
 {
-    ReadServerSieveConfigJob *job = new ReadServerSieveConfigJob(this);
+    auto job = new ReadServerSieveConfigJob(this);
     connect(job, &ReadServerSieveConfigJob::finished, this, &ServerSieveListWidget::slotReadServerSieveConfigDone);
     job->start();
 }
@@ -58,7 +58,7 @@ void ServerSieveListWidget::writeConfig()
 void ServerSieveListWidget::deletePasswords()
 {
     if (!mNeedToRemovePasswordInWallet.isEmpty()) {
-        for (const QString &identifier : qAsConst(mNeedToRemovePasswordInWallet)) {
+        for (const QString &identifier : std::as_const(mNeedToRemovePasswordInWallet)) {
             auto deleteJob = new DeletePasswordJob(QStringLiteral("sieveeditor"));
             deleteJob->setKey(identifier);
             deleteJob->start();
