@@ -7,6 +7,7 @@
 #include "serversievesettings.h"
 #include "sieveeditor_debug.h"
 #include "ui_serversievesettings.h"
+#include <KAuthorized>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <MailTransport/ServerTest>
@@ -77,6 +78,8 @@ ServerSieveSettings::ServerSieveSettings(QWidget *parent)
     ui->testInfo->clear();
     ui->testInfo->hide();
     ui->testProgress->hide();
+    ui->password->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
+    ui->imapPassword->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
 
     ui->safeImapGroup->setId(ui->noRadio, KSieveUi::SieveImapAccountSettings::Unencrypted);
     ui->safeImapGroup->setId(ui->sslRadio, KSieveUi::SieveImapAccountSettings::SSLorTLS);
@@ -387,7 +390,7 @@ void ServerSieveSettings::slotSafetyChanged()
 
     ui->imapAuthenticationCombo->clear();
     addAuthenticationItem(ui->imapAuthenticationCombo, MailTransport::Transport::EnumAuthenticationType::CLEAR);
-    for (int prot : qAsConst(protocols)) {
+    for (int prot : std::as_const(protocols)) {
         addAuthenticationItem(ui->imapAuthenticationCombo, static_cast<MailTransport::Transport::EnumAuthenticationType::type>(prot));
     }
     if (protocols.isEmpty()) {
