@@ -28,7 +28,7 @@ bool SieveEditorManageSieveWidget::refreshList()
 {
     bool noImapFound = true;
     SieveTreeWidgetItem *last = nullptr;
-    for (const SieveEditorUtil::SieveServerConfig &conf : mSieveServerSettings) {
+    for (const SieveEditorUtil::SieveServerConfig &conf : std::as_const(mSieveServerSettings)) {
         last = new SieveTreeWidgetItem(treeView(), last);
         last->setText(0, conf.sieveSettings.serverName + QStringLiteral(" (%1)").arg(conf.sieveSettings.userName));
         last->setIcon(0, QIcon::fromTheme(QStringLiteral("network-server")));
@@ -57,7 +57,7 @@ bool SieveEditorManageSieveWidget::refreshList()
 
 void SieveEditorManageSieveWidget::updateSieveSettings()
 {
-    ReadServerSieveConfigJob *job = new ReadServerSieveConfigJob(this);
+    auto job = new ReadServerSieveConfigJob(this);
     connect(job, &ReadServerSieveConfigJob::finished, this, &SieveEditorManageSieveWidget::slotReadServerSieveConfigDone);
     job->start();
 }
