@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sieveeditorscriptmanagerwidget.h"
@@ -26,8 +13,8 @@
 SieveEditorScriptManagerWidget::SieveEditorScriptManagerWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *hbox = new QHBoxLayout(this);
-    mTreeView = new SieveEditorManageSieveWidget;
+    auto hbox = new QHBoxLayout(this);
+    mTreeView = new SieveEditorManageSieveWidget(this);
     connect(mTreeView, &SieveEditorManageSieveWidget::newScript, this, &SieveEditorScriptManagerWidget::slotNewScript);
     connect(mTreeView, &SieveEditorManageSieveWidget::editScript, this, &SieveEditorScriptManagerWidget::slotEditScript);
     connect(mTreeView, &SieveEditorManageSieveWidget::updateButtons, this, &SieveEditorScriptManagerWidget::slotUpdateButtons);
@@ -43,7 +30,7 @@ SieveEditorScriptManagerWidget::~SieveEditorScriptManagerWidget()
 
 void SieveEditorScriptManagerWidget::slotUpdateButtons(QTreeWidgetItem *item)
 {
-    Q_UNUSED(item);
+    Q_UNUSED(item)
     bool newScriptAction;
     bool editScriptAction;
     bool deleteScriptAction;
